==> ukui-panel_3.14.0.1.orig.tar.gz: ukui-panel-3.14.0.1/plugin-taskbar/ukuitaskbarplugin.cpp <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * Copyright: 2012 Razor team
 *            2014 LXQt team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * Copyright: 2019 Tianjin KYLIN Information Technology Co., Ltd. *
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */


#include "ukuitaskbarplugin.h"

UKUITaskBarPlugin::UKUITaskBarPlugin(const IUKUIPanelPluginStartupInfo &startupInfo):
    QObject(),
    IUKUIPanelPlugin(startupInfo)
{
    translator();
    m_taskBar = new UKUITaskBar(this);
}


UKUITaskBarPlugin::~UKUITaskBarPlugin()
{
    delete m_taskBar;
}

void UKUITaskBarPlugin::realign()
{
    m_taskBar->realign();
}

void UKUITaskBarPlugin::translator()
{
    m_translator = new QTranslator(this);
    QString locale = QLocale::system().name();
    if (locale == "zh_CN") {
        if (m_translator->load(QM_INSTALL)) {
            qApp->installTranslator(m_translator);
        } else {
            qDebug() <<PLUGINNAME<<"Load translations file" << locale << "failed!";
        }
    } else if (locale == "bo_CN") {
        if (m_translator->load(BO_QM_INSTALL)) {
            qApp->installTranslator(m_translator);
        } else {
            qDebug() <<PLUGINNAME<<"Load translations file" << locale << "failed!";
        }
    }
}

==> ukui-panel_4.0.0.0.orig.tar.gz: ukui-panel-4.0.0.0/plugin-taskbar/ukuitaskbarplugin.cpp <==
/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * Copyright: 2012 Razor team
 *            2014 LXQt team
 * Authors:
 *   Alexander Sokoloff <sokoloff.a@gmail.com>
 *
 * Copyright: 2019 Tianjin KYLIN Information Technology Co., Ltd. *
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */


#include "ukuitaskbarplugin.h"

UKUITaskBarPlugin::UKUITaskBarPlugin(const IUKUIPanelPluginStartupInfo &startupInfo):
    QObject(),
    IUKUIPanelPlugin(startupInfo)
{
    translator();
    m_taskBar = new UKUITaskBar(this);
}


UKUITaskBarPlugin::~UKUITaskBarPlugin()
{
    delete m_taskBar;
}

void UKUITaskBarPlugin::realign()
{
    m_taskBar->realignSdk();
}

void UKUITaskBarPlugin::translator()
{
    m_translator = new QTranslator(this);
    QString locale = QLocale::system().name();
    if (locale == "zh_CN") {
        if (m_translator->load(QM_INSTALL)) {
            qApp->installTranslator(m_translator);
        } else {
            qDebug() <<PLUGINNAME<<"Load translations file" << locale << "failed!";
        }
    } else if (locale == "bo_CN") {
        if (m_translator->load(BO_QM_INSTALL)) {
            qApp->installTranslator(m_translator);
        } else {
            qDebug() <<PLUGINNAME<<"Load translations file" << locale << "failed!";
        }
    }
}
